@@ -23,7 +23,7 @@
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
- $Id: //depot/r17.2/p4-python/SpecMgr.cpp#1 $
+ $Id: //depot/r18.2/p4-python/SpecMgr.cpp#1 $
  *******************************************************************************/
 
 /*******************************************************************************
@@ -114,7 +114,6 @@ struct specdata {
 	"Backup;code:319;type:select;len:10;val:enable/disable;;"
 	"View;code:311;type:wlist;words:2;len:64;;"
 	"ChangeView;code:317;type:llist;len:64;;"
-  "RepoView;code:320;type:llist;len:64;;"
     },
     {
 	"depot",
@@ -129,6 +128,24 @@ struct specdata {
 	"Map;code:257;rq;len:64;;"
 	"SpecMap;code:259;type:wlist;len:64;;"
     },
+    {
+	"extension",
+	"ExtName;code:901;type:line;opt:once;len:64;;"
+	"ExtDescription;code:902;type:text;opt:once;len:128;;"
+	"ExtVersion;code:903;type:line;opt:once;len:32;;"
+	"ExtUUID;code:904;type:line;opt:once;len:36;;"
+	"ExtRev;code:905;type:word;opt:once;len:20;;"
+	"ExtMaxScriptTime;code:913;type:word;len:12;;"
+	"ExtMaxScriptMem;code:914;type:word;len:12;;"
+	"ExtAllowedGroups;code:915;type:wlist;len:32;opt:default;;"
+	"ExtEnabled;code:916;type:word;opt:default;len:12;;"
+	"ExtP4USER;code:917;type:word;opt:default;len:12;;"
+	"Name;code:906;type:line;opt:default;len:32;;"
+	"Owner;code:907;type:word;opt:default;len:36;;"
+	"Update;code:908;type:date;opt:always;fmt:L;len:20;;"
+	"Description;code:909;type:text;opt:required;len:128;;"
+	"ExtConfig;code:912;type:text;opt:required;len:256;;"
+    },
     {
 	"group",
 	"Group;code:401;rq;ro;len:32;;"
@@ -215,7 +232,7 @@ struct specdata {
 	"protect",
 	"SubPath;code:502;ro;len:64;;"
 	"Update;code:503;type:date;ro;fmt:L;len:20;;"
-	"Protections;code:501;fmt:C;type:wlist;words:5;opt:default;len:64;;"
+	"Protections;code:501;fmt:C;type:wlist;words:5;opt:default;z;len:64;;"
     },
     {
 	"remote",
@@ -234,7 +251,7 @@ struct specdata {
 	"ArchiveLimits;code:862;type:wlist;words:2;len:64;;"
     },
     {
-  "repo",
+	"repo",
 	"Repo;code:1001;rq;ro;len:128;;"
 	"Owner;code:1002;len:32;;"
 	"Created;code:1003;type:date;ro;fmt:L;len:20;;"
@@ -244,7 +261,7 @@ struct specdata {
 	"DefaultBranch;code:1007;len:32;;"
 	"MirroredFrom;code:1008;len:32;;"
 	"Options;code:1009;type:select;len:10;val:lfs/nolfs;;"
-  	},
+    },
     {
 	"server",
 	"ServerID;code:751;rq;ro;len:32;;"
@@ -253,6 +270,9 @@ struct specdata {
 	"Address;code:754;type:line;len:32;;"
 	"ExternalAddress;code:755;type:line;len:32;;"
 	"Services;code:756;rq;len:128;;"
+	"Options;code:764;type:line;len:32;val:"
+	"nomandatory/mandatory;;"
+	"ReplicatingFrom;code:765;type:line;len:32;;"
 	"Description;code:757;type:text;len:128;;"
 	"User;code:761;type:line;len:64;;"
 	"AllowedAddresses;code:763;type:wlist;len:64;;"
@@ -293,11 +313,11 @@ struct specdata {
     },
     {
 	"triggers",
-	"Triggers;code:551;type:wlist;words:4;len:64;opt:default;"
+	"Triggers;code:551;type:wlist;words:4;len:64;opt:default;z;;"
     },
     {
 	"typemap",
-	"TypeMap;code:601;type:wlist;words:2;len:64;opt:default;"
+	"TypeMap;code:601;type:wlist;words:2;len:64;opt:default;z;;"
     },
     {
 	"user",
@@ -309,7 +329,8 @@ struct specdata {
 	"FullName;code:655;fmt:R;type:line;rq;len:32;;"
 	"JobView;code:656;type:line;len:64;;"
 	"Password;code:657;len:32;;"
-	"AuthMethod;code:662;fmt:L;len:10;val:perforce/ldap;;"
+	"AuthMethod;code:662;fmt:L;len:10;val:"
+	"perforce/perforce+2fa/ldap/ldap+2fa;;"
 	"Reviews;code:658;type:wlist;len:64;;"
     },
     { 0, 0}
